@@ -1,5 +1,5 @@
 from math import trunc
-from .utils import ceil
+from .utils import ceil, jwday, monthcalendarhelper
 from . import gregorian
 
 EPOCH = 1948439.5
@@ -7,14 +7,17 @@ WEEKDAYS = ("al-'ahad", "al-'ithnayn",
             "ath-thalatha'", "al-'arb`a'",
             "al-khamis", "al-jum`a", "as-sabt")
 
+HAS_29_DAYS = (2, 4, 6, 8, 10)
+HAS_30_DAYS = (1, 3, 5, 7, 9, 11)
+
 
 def leap(year):
-    '''LEAP_ISLAMIC  --  Is a given year a leap year in the Islamic calendar ?'''
+    '''Is a given year a leap year in the Islamic calendar'''
     return (((year * 11) + 14) % 30) < 11
 
 
 def to_jd(year, month, day):
-    '''TO_JD  --  Determine Julian day from Islamic date'''
+    '''Determine Julian day count from Islamic date'''
     return (day + ceil(29.5 * (month - 1)) + (year - 1) * 354 + trunc((3 + (11 * year)) / 30) + EPOCH) - 1
 
 
@@ -27,8 +30,22 @@ def from_jd(jd):
     day = int(jd - to_jd(year, month, 1)) + 1
     return (year, month, day)
 
+
 def from_gregorian(year, month, day):
     return from_jd(gregorian.to_jd(year, month, day))
 
+
 def to_gregorian(year, month, day):
     return gregorian.from_jd(to_jd(year, month, day))
+
+
+def month_length(year, month):
+    if month in HAS_30_DAYS or (month == 12 and leap(year)):
+        return 30
+
+    return 29
+
+def monthcalendar(year, month):
+    start_weekday = jwday(to_jd(year, month, 1))
+    monthlen = month_length(year, month)
+    return monthcalendarhelper(start_weekday, monthlen)
